@@ -4,6 +4,7 @@ import sys
 import argparse
 from argument_esa_model.esa import ESA
 
+e = None
 
 def create_argparser():
     parser = argparse.ArgumentParser()
@@ -15,7 +16,9 @@ def create_argparser():
     return parser
 
 def model_topic(path_matrix,path_model,path_vocab,similarity,text):
-    e = ESA(matrix_path = path_matrix, model_path = path_model, vocab_path = path_vocab, similarity = similarity)
+    global e
+    if e == None:
+        e = ESA(matrix_path = path_matrix, model_path = path_model, vocab_path = path_vocab, similarity = similarity)
     result = e.process(text, False)
     return result
 
